@@ -9,13 +9,15 @@ urlpatterns = patterns('sanza.Crm.views',
     url(r'^create-entity/(?P<entity_type_id>\d+)/$', 'create_entity', name='crm_create_entity'),
     url(r'^delete-entity/(?P<entity_id>\d+)/$', 'delete_entity', name='crm_delete_entity'),
     url(r'^add-contact/(?P<entity_id>\d+)/$', 'add_contact', name='crm_add_contact'),
-    url(r'^add-single-contact//$', 'add_single_contact', name='crm_add_single_contact'),
+    url(r'^add-single-contact/$', 'add_single_contact', name='crm_add_single_contact'),
     url(r'^delete-contact/(?P<contact_id>\d+)/$', 'delete_contact', name='crm_delete_contact'),
     url(r'^edit-contact/(?P<contact_id>\d+)/$', 'edit_contact', name='crm_edit_contact'),
     url(r'^edit-contact-advanced/(?P<contact_id>\d+)/$', 'edit_contact', kwargs={'mini': False}, name='crm_edit_contact_advanced'),
     url(r'^edit-contact-on-create-entity/(?P<contact_id>\d+)/$', 'edit_contact', kwargs={'go_to_entity': True}, name='crm_edit_contact_after_entity_created'),
     url(r'^view-contact/(?P<contact_id>\d+)/$', 'view_contact', name='crm_view_contact'),
     url(r'^same-as/(?P<contact_id>\d+)/$', 'same_as', name='crm_same_as'),
+    url(r'^add-relationship/(?P<contact_id>\d+)/$', 'add_relationship', name='crm_add_relationship'),
+    url(r'^delete-relationship/(?P<contact_id>\d+)/(?P<relationship_id>\d+)/$', 'delete_relationship', name='crm_delete_relationship'),
     url(r'^add-entity-to-group/(?P<entity_id>\d+)/$', 'add_entity_to_group', name='crm_add_entity_to_group'),
     url(r'^add-contact-to-group/(?P<contact_id>\d+)/$', 'add_contact_to_group', name='crm_add_contact_to_group'),
     url(r'^get-group-suggest-list/$', 'get_group_suggest_list', name='crm_get_group_suggest_list'),
